Module: Google::Cloud::MediaTranslation
- Defined in:
- lib/google/cloud/media_translation.rb,
lib/google/cloud/media_translation/version.rb
Constant Summary collapse
- VERSION =
"0.8.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.media_translation| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-media_translation library.
-
.speech_translation_service(version: :v1beta1, &block) ⇒ ::Object
Create a new client object for SpeechTranslationService.
-
.speech_translation_service_available?(version: :v1beta1) ⇒ boolean
Determines whether the SpeechTranslationService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.media_translation| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-media_translation library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
138 139 140 141 142 |
# File 'lib/google/cloud/media_translation.rb', line 138 def self.configure yield ::Google::Cloud.configure.media_translation if block_given? ::Google::Cloud.configure.media_translation end |
.speech_translation_service(version: :v1beta1, &block) ⇒ ::Object
Create a new client object for SpeechTranslationService.
By default, this returns an instance of
Google::Cloud::MediaTranslation::V1beta1::SpeechTranslationService::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the SpeechTranslationService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the SpeechTranslationService service. You can determine whether the method will succeed by calling speech_translation_service_available?.
About SpeechTranslationService
Provides translation from/to media types.
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/cloud/media_translation.rb', line 72 def self.speech_translation_service version: :v1beta1, &block require "google/cloud/media_translation/#{version.to_s.downcase}" package_name = Google::Cloud::MediaTranslation .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::MediaTranslation.const_get(package_name).const_get(:SpeechTranslationService) service_module.const_get(:Client).new(&block) end |
.speech_translation_service_available?(version: :v1beta1) ⇒ boolean
Determines whether the SpeechTranslationService service is supported by the current client. If true, you can retrieve a client object by calling speech_translation_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SpeechTranslationService service, or if the versioned client gem needs an update to support the SpeechTranslationService service.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/google/cloud/media_translation.rb', line 94 def self.speech_translation_service_available? version: :v1beta1 require "google/cloud/media_translation/#{version.to_s.downcase}" package_name = Google::Cloud::MediaTranslation .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::MediaTranslation.const_get package_name return false unless service_module.const_defined? :SpeechTranslationService service_module = service_module.const_get :SpeechTranslationService service_module.const_defined? :Client rescue ::LoadError false end |